:root {
    --primary-color: #c9a51a;
    --cyan: #0f8073;
    --gray: rgba(45, 45, 45, 1);
    --gray-transparent: rgba(45, 45, 45, 0.88);
    --title-font: 'Passion One', cursive;
}

.title, h1, h2, h3, h4, h5, h6{
    font-family: var(--title-font);
    color: #2d2d2d;
    font-weight: 400;
}
body{
    font-family: 'Open Sans', sans-serif;
    margin: 0;
    overflow-x: hidden;
}

h1 {
    font-size: 62px;
    margin: 0;
}

h2 {
    font-size: 42px;
    margin: 0;
}

h2.text-center {
    color: var(--primary-color);
    margin-bottom: 70px;
}

h3 {
    font-size: 20px;
    margin: 0;
}

p{
    font-size: 18px;
    margin: 0;
}

p.title{
    font-size: 25px;
    font-weight: 700;
}

.quote{
    font-size: 42px;
    font-family: var(--title-font);
    color: var(--gray);
}

hr{
    width: 30%;
    display: inline-block;
    height: 6px;
    border: none;
    background: var(--primary-color);
    border-radius: 5px;
}

section{
    margin-bottom: 20px;
}

.flex-row{
    display: flex;
    flex-direction: row;
}

.flex-col{
    display: flex;
    flex-direction: column;
}

.flex-sb{
    justify-content: space-between;
}

.ac-center{
    align-content: center;
}

.ai-center{
    align-items: center;
}

.text-center{
    text-align: center;
}

.bg-colored{
    color: white;
    background-color: var(--cyan);
}

.bg-colored hr{
    border-color: white;
}

.maincontainer{
    width: 1200px;
    margin: auto;
    padding: 60px 0 20px 0;
}

.content .container {
    width: 80%;
    margin-left: auto;
}

.btn{
    text-transform: uppercase;
    color: white;
    background-color: #2d2d2d;
    margin-bottom: 20px;
    border: none;
    border-radius: 10px;
    padding: 17px 23px;
    font-size: 22px;
    font-weight: bold;
    text-decoration: none;
    text-align: center;
    cursor: pointer;
}
.btn.is-disabled{
    background: lightgray !important;
    color: white !important;
    cursor: not-allowed;
}

/* start */

.start{
    min-height: 700px;
    color: white;
    background-color: var(--primary-color);
    background-size: cover;
    background-position: center;
    background-repeat: no-repeat;
}

.start .stats{
    min-width: 350px;
    height: 80px;
    color: var(--primary-color);
}

.start .stats > div{
    height: 100%;
    background-color: var(--gray-transparent);
}

.ai-center > .side {
    flex-grow: 1;
    height: 100% !important;
    border-radius: 0 !important;
    padding: 0 !important;
}

.start p#stats{
    font-family: 'Passion One', cursive;
    font-size: 60px;
    font-weight: 400;
    text-align: center;
    color: var(--primary-color);
}

.start .text-center{
    font-size: 21px;
    font-weight: bold;
    margin-top: -10px;
}

.start .stats img{
    width: 50px;
    height: 50px;
    margin-left: 25px;
    border-radius: 50%;
    padding: 10px;
    background-color: var(--primary-color);
}

.start .maincontainer{
    margin-top: 20px;
}

.start .social img{
    width: 50px;
}

.mainform{
    border-radius: 12px;
    width: 100%;
    padding: 22px 28px;
    background-color: var(--gray-transparent);
    max-width: 400px;
}

.mainform > h3 {
    font-weight: normal;
    font-size: 28px;
}

.mainform h3 > span{
    color: var(--primary-color);
}

.mainform hr{
    width: 100%;
}

.mainform input[type="text"], .mainform input[type="email"]{
    border-radius: 8px;
    border: 1px solid grey;
    font-size: 20px;
    margin: 6px 0;
    padding: 5px 12px;
    width: 92%;
}
.mainform-details > p {
    font-size: 13px;
}

.mainform label{
    font-size: 13px;
}

.mainform .btn {
    background-color: var(--primary-color);
}
.btn.is-primary{
    background: var(--primary-color);
}
.btn-container {
    width: 80%;
    margin: 20px auto;
}

.btn-container > a {
    display: inline-block;
}

#signature-result {
    display: none;
}

#signature-result > p {
    margin-bottom: 40px;
    margin-top: 40px;
}

#signature-result > .social {
    width: 60%;
    margin: 0 auto;
}

/* ##### */
.has-number-left{
    display: flex;
    align-items: center;
}
.has-number-left > div:first-child{
    font-family: var(--title-font);
    font-size: 80px;
    margin-left: 0;
}
.has-number-left > div{
    font-size: 25px;
    margin-left: calc(20px + 2vw);
    color: var(--primary-color);
    font-weight: 700;
}
.decideurs .maincontainer {
    padding: 30px 0;
}

.decideurs .btn {
    max-width: 300px;
}

.paragraph {
    color: var(--gray);
    font-size: 25px;
    text-align: justify;
    margin: 20px 0;
}
.paragraph a{
    color: var(--gray);
    text-decoration: underline;
}

.content .main{
    width: 70%;
}

.content .sidebar{
    width: 20%;
    margin-top: 60px;
    min-width: 260px;
}

.sidebar h3{
    font-size: 45px;
    margin-bottom: 20px;
}

.sidebar p a{
    display: block;
    margin-bottom: 10px;
    color: white;
}

.sidebar .bg-colored{
    margin-top: 5px;
    border-top-left-radius: 50px;
    border-bottom-left-radius: 50px;
    padding: 13px 10px 10px;
}

.sidebar .social img{
    width: 40px;
}

.sidebar .social a:first-of-type img{
    transform: translateX(5px);
}

.sidebar .content{
    color: white;
    background-color: var(--gray);
    margin: 50px auto;
    border-top-left-radius: 50px;
    border-bottom-left-radius: 50px;
    padding: 40px 25px;
}

.bottom-button{
    padding: 40px;
}

/* Footer */

footer{
    width: 800px;
    height: 80px;
    margin: auto;
    padding: 40px 0;
}

footer a{
    text-decoration: none;
    color: black;
}

footer p{
    font-weight: 900;
}

footer #email{
    color: var(--primary-color);
}

footer .social a{
    display: flex;
    justify-content: center;
    align-content: center;
    width: 25px;
    height: 25px;
    margin-right: 5px;
    border: 2px solid var(--primary-color);
    border-radius: 50%;
    padding: 3px;
}

footer .social img {
    width: 20px;
}

/* End of footer*/

/* No JS handling */
.display-if-js {
    display: none;
}


.decideur-container > div{
    flex-basis: 0;
    flex-shrink: 0;
}
.mail-underlined {
    padding: 13px 0 5px 0;
    color: darkgray;
    border-bottom: 2px solid lightgray;
}
.mail-to-tag{
    padding: 5px 18px 5px 12px;
    position: relative;
    color: white;
    background-color: var(--cyan);
    border-radius: 8px;
}
.mail-to-tag > .close{
    position: absolute;
    right: 5px;
    top: 1px;
    font-weight: bold;
    font-size: 12px;
    cursor: pointer;
}
.mail-to-tag + .mail-to-tag {
    margin-left: 15px;
}
.mail-underlined > textarea{
    color: var(--gray);
    font-family: Open_sans, sans-serif;
    width: 100%;
    height: 330px;
    font-size: 16px;
    border: none;
}
.mail-right-col input{
    background: white;
    padding: 5px 12px;
    color: #161616;
    width: 100%;
    border-radius: 5px;
    border: none;
    font-size: 18px;
}
.mail-right-col .input-holder{
    margin-top: 12px;
}
.share{
    font-weight: 700;
    color: var(--gray);
}
.has-text-shadowed{
    color: white;
    text-shadow: 0 0 10px black;
}
#top-text{
    margin-right: 30px;
    min-width: 375px;
}
.is-marginless{
    margin: 0 !important;
}
