# Generated by Django 3.0 on 2020-04-20 12:57

import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ('appel_crises', '0002_auto_20200420_1244'),
    ]

    operations = [
        migrations.AlterField(
            model_name='signature',
            name='created',
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
    ]
