ASSOCIATIONS = [
    ("https://pour-un-reveil-ecologique.org/", "Alter'Actions"),
    ("https://pour-un-reveil-ecologique.org/", "Animafac"),
    ("https://pour-un-reveil-ecologique.org/", "APF France Handicap"),
    (
        "https://pour-un-reveil-ecologique.org/",
        "Association nationale des étudiants en médecine de France",
    ),
    ("https://pour-un-reveil-ecologique.org/", "ATD-Quart Monde"),
    ("https://pour-un-reveil-ecologique.org/", "Avenir climatique"),
    (
        "https://pour-un-reveil-ecologique.org/",
        "B.A.-BA Fédération des associations étudiantes d'Aix-en-Provence",
    ),
    ("https://pour-un-reveil-ecologique.org/", "C3D"),
    ("https://pour-un-reveil-ecologique.org/", "Campus de la Transition"),
    ("https://pour-un-reveil-ecologique.org/", "Citoyens Pour Le Climat"),
    ("https://pour-un-reveil-ecologique.org/", "CliMates"),
    ("https://pour-un-reveil-ecologique.org/", "Colibris"),
    ("https://pour-un-reveil-ecologique.org/", "Comité 21"),
    ("https://pour-un-reveil-ecologique.org/", "Convergence Infirmière"),
    ("https://pour-un-reveil-ecologique.org/", "COP1"),
    ("https://pour-un-reveil-ecologique.org/", "COP2 étudiante"),
    ("https://pour-un-reveil-ecologique.org/", "Emmaus"),
    ("https://pour-un-reveil-ecologique.org/", "Entrepreneurs d'Avenir"),
    ("https://pour-un-reveil-ecologique.org/", "FEF"),
    ("https://pour-un-reveil-ecologique.org/", "FFJ"),
    ("https://pour-un-reveil-ecologique.org/", "Filière Paysanne "),
    ("https://pour-un-reveil-ecologique.org/", "FNE"),
    ("https://pour-un-reveil-ecologique.org/", "Fondation Nicolas Hulot"),
    ("https://pour-un-reveil-ecologique.org/", "Gilets Citoyens"),
    ("https://pour-un-reveil-ecologique.org/", "Greenlobby"),
    ("https://pour-un-reveil-ecologique.org/", "Groupe SOS Transition écologique"),
    ("https://pour-un-reveil-ecologique.org/", "I4CE"),
    ("https://pour-un-reveil-ecologique.org/", "Il est encore temps"),
    ("https://pour-un-reveil-ecologique.org/", "Institut Rousseau"),
    ("https://pour-un-reveil-ecologique.org/", "Institut Veblen"),
    ("https://pour-un-reveil-ecologique.org/", "La Fresque du climat"),
    ("https://pour-un-reveil-ecologique.org/", "Latitudes"),
    ("https://pour-un-reveil-ecologique.org/", "Les greniers d'abondance"),
    ("https://pour-un-reveil-ecologique.org/", "Les Shifters"),
    ("https://pour-un-reveil-ecologique.org/", "Lobby Citoyen (CLIC)"),
    ("https://pour-un-reveil-ecologique.org/", "Low Carbon France"),
    ("https://pour-un-reveil-ecologique.org/", "Lumia"),
    ("https://pour-un-reveil-ecologique.org/", "Négawatt"),
    ("https://pour-un-reveil-ecologique.org/", "NOISE"),
    ("https://pour-un-reveil-ecologique.org/", "Notre Affaire à Tous"),
    ("https://pour-un-reveil-ecologique.org/", "On est prêt"),
    ("https://pour-un-reveil-ecologique.org/", "Paris-Bascule"),
    ("https://pour-un-reveil-ecologique.org/", "Pour un réveil écologique"),
    ("https://pour-un-reveil-ecologique.org/", "Printemps écologique"),
    ("https://pour-un-reveil-ecologique.org/", "Profs en Transition"),
    ("https://pour-un-reveil-ecologique.org/", "REFEDD"),
    ("https://pour-un-reveil-ecologique.org/", "Resilience"),
    ("https://pour-un-reveil-ecologique.org/", "Sciences Citoyennes"),
    ("https://pour-un-reveil-ecologique.org/", "SOS Maires"),
    ("https://pour-un-reveil-ecologique.org/", "T4E/Up for Europe"),
    ("https://pour-un-reveil-ecologique.org/", "The Shift Project"),
    ("https://pour-un-reveil-ecologique.org/", "UNICEF"),
    ("https://pour-un-reveil-ecologique.org/", "Unis pour la planète"),
    ("https://pour-un-reveil-ecologique.org/", "URIOPSS Nouvelle-Aquitaine"),
    ("https://pour-un-reveil-ecologique.org/", "WARN"),
    ("https://pour-un-reveil-ecologique.org/", "WWF"),
    ("https://pour-un-reveil-ecologique.org/", "Yon A Lot - L'un à l'autre"),
    ("https://pour-un-reveil-ecologique.org/", "Youth For Climate France"),
]
