@media screen and (max-width:1300px) {
    .maincontainer {
        width: 1000px;
        margin: auto;
        padding: 40px 10px 15px 10px;
    }

    .start{
        min-height: 500px;
    }

    .start h1{
        font-size: 56px;
    }

    footer{
        width: 95%;
        padding: 40px 3% 15px 3%;
    }
}

@media screen and (max-width:800px) {
    .content .container {
        width: 100%;
    }
    .content .main{
        width: 90%;
    }
    .maincontainer {
        width: 80%;
        flex-direction: column;
        align-items: center;
    }

    .start{
        min-height: 1000px;
    }

    .start h1{
        font-size: 50px;
    }

    .content{
        flex-direction: column;
        align-items: center;
    }

    .sidebar{
        display: none;
    }
    .decideur-container{
        flex-direction: column;
    }
    .decideur-why{
        margin-top: 40px;
    }
    #depute-form{
        flex-direction: column;
    }
    .paragraph{
        font-size: 16px;
    }
}

@media screen and (max-width:600px) {
    .maincontainer {
        padding: 20px 2px 10px 2px;
    }

    .start{
        min-height: 1200px;
    }

    .start h1{
        font-size: 36px;
    }

    footer .contact{
        text-align: right;
    }

    footer .social{
        justify-content: right;
    }
    #top-text{
        margin-right: 0;
        min-width: initial;
    }
    .paragraph{
        font-size: 16px;
    }
    p{
        font-size: 15px;
        margin: 0;
    }
    .quote{
        font-size: 35px;
    }
    .has-number-left > div{
        font-size: 18px;
    }
    h2 {
        font-size: 30px;
    }
}
