{% extends "base.html" %}
{% load static %}

{% block content %}
    <section>
        <div>
            <h1>Signez l'appel ici.</h1>
        </div>
        <div class="maincontainer">
            <form action="{% url 'sign' %}" method="POST">
                {% csrf_token %}
                <div>
                    <label for="firstname">Prénom</label>
                    <input id="firstname" type="text" placeholder="Prénom" name="firstname" required>
                </div>
                <div>
                    <label for="surname">Nom</label>
                    <input type="text" placeholder="Nom" name="surname" id="surname" required>
                </div>
                <div>
                    <label for="email">Email</label>
                    <input type="email" placeholder="Email" name="email" id="email" required>
                </div>

                <input type="checkbox" id="newsletter"> <label for="newsletter">Accepter la première
                condition</label><br>
                <input type="checkbox" id="other"> <label for="other">Accepter l'autre condition</label>
                <input type="submit" value="Signer l'appel" class="button">
            </form>
        </div>
    </section>
{% endblock %}
