from typing import List

from appel_crises.mailer import MailingPerson, mailing_person

GVT: List[MailingPerson] = [
    mailing_person("hadrien.renaudlebret+0@gmail.com", "Emmanuel Macron"),
    mailing_person("hadrien.renaudlebret+1@gmail.com", "Emmanuel Macron"),
    mailing_person("hadrien.renaudlebret+2@gmail.com", "Emmanuel Macron"),
    mailing_person("hadrien.renaudlebret+3@gmail.com", "Emmanuel Macron"),
    mailing_person("hadrien.renaudlebret+4@gmail.com", "Emmanuel Macron"),
    mailing_person("hadrien.renaudlebret+5@gmail.com", "Emmanuel Macron"),
    mailing_person("hadrien.renaudlebret+6@gmail.com", "Emmanuel Macron"),
    mailing_person("hadrien.renaudlebret+7@gmail.com", "Emmanuel Macron"),
    mailing_person("hadrien.renaudlebret+8@gmail.com", "Emmanuel Macron"),
    mailing_person("hadrien.renaudlebret+9@gmail.com", "Emmanuel Macron"),
    mailing_person("hadrien.renaudlebret+10@gmail.com", "Emmanuel Macron"),
    mailing_person("hadrien.renaudlebret+11@gmail.com", "Emmanuel Macron"),
    mailing_person("hadrien.renaudlebret+12@gmail.com", "Emmanuel Macron"),
    mailing_person("hadrien.renaudlebret+13@gmail.com", "Emmanuel Macron"),
    mailing_person("hadrien.renaudlebret+14@gmail.com", "Emmanuel Macron"),
    mailing_person("hadrien.renaudlebret+15@gmail.com", "Emmanuel Macron"),
    mailing_person("hadrien.renaudlebret+16@gmail.com", "Emmanuel Macron"),
    mailing_person("hadrien.renaudlebret+17@gmail.com", "Emmanuel Macron"),
    mailing_person("hadrien.renaudlebret+18@gmail.com", "Emmanuel Macron"),
    mailing_person("hadrien.renaudlebret+19@gmail.com", "Emmanuel Macron"),
    mailing_person("hadrien.renaudlebret+20@gmail.com", "Emmanuel Macron"),
]
