# Generated by Django 3.0 on 2020-04-20 12:44

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ('appel_crises', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='signature',
            name='email',
            field=models.EmailField(max_length=100, unique=True),
        ),
    ]
