# Generated by Django 3.0.5 on 2020-04-29 19:52

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('appel_crises', '0008_signature_from_asso'),
    ]

    operations = [
        migrations.CreateModel(
            name='CallOutEmail',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('content', models.TextField()),
                ('subject', models.CharField(max_length=200)),
                ('send_to_government', models.BooleanField()),
                ('send_to_depute', models.BooleanField()),
                ('sender', models.CharField(max_length=100)),
                ('from_email', models.CharField(max_length=60)),
                ('postal_code', models.CharField(max_length=10)),
                ('email_sent_at', models.DateTimeField(blank=True, db_index=True, null=True)),
                ('verified_at', models.DateTimeField(blank=True, db_index=True, null=True)),
                ('from_asso', models.CharField(blank=True, max_length=40, null=True)),
            ],
        ),
    ]
